==> kdesdk-4.6.5.tar.bz2: kdesdk-4.6.5/okteta/mobile/kasten/controllers/documentsystem/loader/loaderactioncontroller.cpp <==
/*
    This file is part of the Kasten Framework, part of the KDE project.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "loaderactioncontroller.h"

// Kasten core
#include <documentsyncmanager.h>
// KDE
#include <KLocale>
// Qt
#include <QtGui/QMenuBar>


namespace Kasten
{

static const char AllFileNamesFilter[] = "*";  // krazy:exclude=doublequote_chars


LoaderActionController::LoaderActionController( DocumentSyncManager* syncManager, QMenuBar* menuBar )
  : mSyncManager( syncManager )
{
    menuBar->addAction( i18n("Open"), this, SLOT(load()) );
}


void LoaderActionController::setTargetModel( AbstractModel* model )
{
Q_UNUSED( model )
}

void LoaderActionController::load()
{
    mSyncManager->load();
}

LoaderActionController::~LoaderActionController()
{
}

}

==> kdesdk-4.7.41.tar.bz2: kdesdk-4.7.41/okteta/mobile/kasten/controllers/documentsystem/loader/loaderactioncontroller.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "loaderactioncontroller.h"

// Kasten core
#include <documentsyncmanager.h>
// KDE
#include <KLocale>
#include <KFileDialog>
// Qt
#include <QtGui/QMenuBar>


namespace Kasten
{

static const char AllFileNamesFilter[] = "*";  // krazy:exclude=doublequote_chars


LoaderActionController::LoaderActionController( DocumentSyncManager* syncManager, QMenuBar* menuBar )
  : mSyncManager( syncManager )
{
    menuBar->addAction( i18n("Open"), this, SLOT(load()) );
}


void LoaderActionController::setTargetModel( AbstractModel* model )
{
Q_UNUSED( model )
}

void LoaderActionController::load()
{
    static const QString allFileNamesFilter = QLatin1String(AllFileNamesFilter);
    const KUrl::List urls =
        KFileDialog::getOpenUrls( QString()/*mWorkingUrl.url()*/, allFileNamesFilter, /*mWidget*/0 );

    foreach( const KUrl& url, urls )
        mSyncManager->load( url );
}

LoaderActionController::~LoaderActionController()
{
}

}
